#!/usr/bin/bash

#
# TODO: Factorize for Mageia 2
#

KRCFG="$(which kreadconfig)"

if [ ! -z "$KRCFG" ]; then # Check if kde is installed, otherwise do nothing

    # "Desktop" Mageia icons"
    MGADESK=$(kreadconfig --group "Mageia" --key "MageiaDesktopFiles" --default "false")

    if [ ! "$MGADESK" = "true" ]; then
        # TODO: We need to handle default => Default too 
        PROD=$(sed 's/.*product=\(.*\)/\L\1/' < /etc/product.id)
        # We should handle i18n dir modes in xgd user dirs
        DIR=$(eval "echo $(kreadconfig --file $HOME/.config/user-dirs.dirs --key XDG_DESKTOP_DIR)" )
        if [ -z "${DIR}" ]; then
            DIR="$HOME/Desktop"
        fi

        if [ ! -d "${DIR}" ]; then
            mkdir -p "${DIR}"
        fi

        if [ -n "$PROD" -a -d "/usr/share/dist/desktop-files/${PROD}" ]; then  
            cp -f /usr/share/dist/desktop-files/${PROD}/*.desktop "${DIR}"
        fi

        # Copy the "Trash" icon on the desktop
        cp -f /usr/share/apps/kio_desktop/directory.trash "${DIR}/org.kde.trash.desktop"

        kwriteconfig --group "Mageia" --key "MageiaDesktopFiles" --type "bool" 1
    fi

    # Add .directory to XDG_*_DIR
    ICONSXDGDIR=$(kreadconfig --group "Mageia" --key "IconsXdgDir" --default "false")

    if [ ! "$ICONSXDGDIR" = "true" ]; then

        MUSICDIR=$(eval "echo $(kreadconfig --file $HOME/.config/user-dirs.dirs --key XDG_MUSIC_DIR)" )
        if [ -z "$MUSICDIR" ]; then
            MUSICDIR="$HOME/Music"
        fi

        if [ ! -e "$MUSICDIR/.directory" ]; then
            cat >> "$MUSICDIR/.directory" << EOF
[Desktop Entry]
Hidden=true
Icon=folder-sound
EOF
        fi


        DLDIR=$(eval "echo $(kreadconfig --file $HOME/.config/user-dirs.dirs --key XDG_DOWNLOAD_DIR)" )
        if [ -z "$DLDIR" ]; then
            DLDIR="$HOME/Downloads"
        fi

        if [ ! -e "$DLDIR/.directory" ]; then
            cat >> "$DLDIR/.directory" << EOF
[Desktop Entry]
Hidden=true
Icon=folder-downloads
EOF
        fi


        DOCDIR=$(eval "echo $(kreadconfig --file $HOME/.config/user-dirs.dirs --key XDG_DOCUMENTS_DIR)" )
        if [ -z "$DOCDIR" ]; then
            DOCDIR="$HOME/Documents"
        fi

        if [ ! -e "$DOCDIR/.directory" ]; then
            cat >> "$DOCDIR/.directory" << EOF
[Desktop Entry]
Hidden=true
Icon=folder-documents
EOF
        fi


        PICTUREDIR=$(eval "echo $(kreadconfig --file $HOME/.config/user-dirs.dirs --key XDG_PICTURES_DIR)" )
        if [ -z "$PICTUREDIR" ]; then
            PICTUREDIR="$HOME/Pictures"
        fi

        if [ ! -e "$PICTUREDIR/.directory" ]; then
            cat >> "$PICTUREDIR/.directory" << EOF
[Desktop Entry]
Hidden=true
Icon=folder-image
EOF
        fi


        VIDEOSDIR=$(eval "echo $(kreadconfig --file $HOME/.config/user-dirs.dirs --key XDG_VIDEOS_DIR)" )
        if [ -z "$VIDEOSDIR" ]; then
            VIDEOSDIR="$HOME/Videos"
        fi

        if [ ! -e "$VIDEOSDIR/.directory" ]; then
            cat >> "$VIDEOSDIR/.directory" << EOF
[Desktop Entry]
Hidden=true
Icon=folder-video
EOF
        fi
        kwriteconfig --group "Mageia" --key "IconsXdgDir" --type "bool" 1
    fi

    # remove cache
    MGARMCACHE=$(kreadconfig --group "Mageia" --key "Mga3Cache" --default "false")

    if [ ! "$MGARMCACHE" = "true" ]; then
        rm -f $HOME/.kde4/cache-`hostname`/plasma-svgelements-default
        rm -f $HOME/.kde4/cache-`hostname`/icon-cache.kcache
        rm -f $HOME/.kde4/cache-`hostname`/plasma_theme_default.kcache
        rm -rf $HOME/.kde4/cache-`hostname`/plasma-wallpapers
        
        # obsoleting iaora
        if kreadconfig --group "General" --key "ColorScheme" --default "none" |grep -q "Ia Ora"; then
            kwriteconfig --group "General" --key "ColorScheme" "Oxygen"
        fi
        if [ "`kreadconfig --group 'General' --key 'widgetStyle' --default 'none'`" = "iaorakde" ]; then
            kwriteconfig --group "General" --key "widgetStyle" "Oxygen"
        fi
        if [ "`kreadconfig --file 'kwinrc' --group 'Style' --key 'PluginLib' --default 'none'`" = "kwin3_iaora" ]; then
            kwriteconfig --file "kwinrc" --group "Style" --key "PluginLib" "kwin3_oxygen"
        fi
        
        kwriteconfig --group "Mageia" --key "Mga3Cache" --type "bool" 1
    fi

    MGA5RMCACHE=$(kreadconfig --group "Mageia" --key "Mga5Cache" --default "false")
    #TODO: Add into a function to factorize the code
    if [ ! "$MGA5RMCACHE" = "true" ]; then
	    rm -f $HOME/.kde4/cache-`hostname`/plasma-svgelements-default
	    rm -f $HOME/.kde4/cache-`hostname`/icon-cache.kcache
	    rm -f $HOME/.kde4/cache-`hostname`/plasma_theme_default.kcache
	    rm -rf $HOME/.kde4/cache-`hostname`/plasma-wallpapers

	    kwriteconfig --group "Mageia" --key "Mga5Cache" --type "bool" 1
    fi

# end of main if: all the changes should be done inside this main if
fi

